;; Generated package description from js2-mode.el  -*- no-byte-compile: t -*-
(define-package "js2-mode" "20201220" "Improved JavaScript editing mode" '((emacs "24.1") (cl-lib "0.5")) :keywords '("languages" "javascript") :authors '(("Steve Yegge" . "steve.yegge@gmail.com") ("mooz" . "stillpedant@gmail.com") ("Dmitry Gutov" . "dgutov@yandex.ru")) :maintainer '("Steve Yegge" . "steve.yegge@gmail.com") :url "https://github.com/mooz/js2-mode/")
